*****************
Utility functions
*****************

.. automodule:: dune.mmesh
  :noindex:
  :members: interfaceIndicator, normal, distance, domainMarker, interfaceDomainMarker, edgeMovement, interfaceEdgeMovement
